@@ -2,6 +2,7 @@
 //! Main entrypoint: [`test::Compiler`]
 
 use std::{
+    fmt,
     io::{self, BufReader},
     path::PathBuf,
     process::{Command, Stdio},
@@ -91,6 +92,15 @@ pub enum TestFnType {
     Bench,
 }
 
+impl fmt::Display for TestFnType {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Self::Test => write!(f, "test"),
+            Self::Bench => write!(f, "bench"),
+        }
+    }
+}
+
 /// Specify tests and benches based on their name
 #[derive(Debug, Clone, Eq, PartialEq, Hash)]
 pub enum NameSpec {
@@ -152,6 +162,8 @@ pub enum TypeSpec {
     Examples,
     /// Doctests
     Doc,
+    /// Whatever `cargo test` tests if you specify nothing
+    Unspecified,
 }
 
 impl TypeSpec {
@@ -319,6 +331,7 @@ impl Compiler {
             TypeSpec::Doc => cmd.arg("--doc"),
             TypeSpec::Example(name) => cmd.args(&["--example", name]),
             TypeSpec::Examples => cmd.arg("--examples"),
+            TypeSpec::Unspecified => &mut cmd,
         };
 
         let mut cmd = cmd.spawn()?;
@@ -335,10 +348,7 @@ impl Compiler {
                     handle_compiler_msg(msg, &mut self.on_compiler_msg)
                 }
                 cargo_metadata::Message::CompilerArtifact(art) => {
-                    if matches!(self.test_type, TypeSpec::Integration(_) | TypeSpec::Integrations)
-                        // test means integration test specifically
-                        && !art.target.kind.iter().any(|k| k == "test")
-                    {
+                    if !art.profile.test {
                         // cargo --test builds binaries so that integration tests can run them.
                         // See <https://github.com/rust-lang/cargo/issues/7958>
                         continue;
@@ -507,6 +517,20 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_unspecified() -> Result {
+        init();
+
+        let artifacts = Compiler::new(NameSpec::substring("test_in_lib"), TypeSpec::Unspecified)
+            .workspace("samples/hello_world")
+            .compile()?;
+
+        let tests: Vec<TestFn> = artifacts.into_iter().flat_map(|a| a.tests).collect();
+        assert_eq!(2, tests.len());
+
+        Ok(())
+    }
+
     #[test]
     fn test_in_example() -> Result {
         init();
